"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

require("core-js/modules/es6.object.define-property");

require("core-js/modules/es6.function.name");

require("core-js/modules/web.dom.iterable");

require("core-js/modules/es6.array.for-each");

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

/*
 * Next Avenues
 *
 * (c) Samuel Joos
 *
 * Based on the work of
 * (c) Harminder Virk <virk@adonisjs.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
*/

/**
 * Group class is used to group routes with
 * common behavior. For example prefixing a bunch
 * of routes.
 *
 * An instance of group is obtained by calling the
 * `router.group` method on [Router](https://github.com/samueljoos/next-avenues/blob/master/docs/router.md)
 * class.
 *
 * @class Group
 * @constructor
 *
 */
var Group =
/*#__PURE__*/
function () {
  function Group(routes) {
    _classCallCheck(this, Group);

    this._routes = routes;
  }
  /**
   * @description
   * Give a name to a group of routes.
   * This will prefix all routes name.
   * Also see [Route.as](https://github.com/samueljoos/next-avenues/blob/master/docs/route.md#asname)
   *
   * @function as
   * @param {string} name Prefix for the route names seperated by a '.'.
   * @returns {Group}
   *
   * @example
   * router
   *   .group(() => {
   *      router.add('/', 'dashboard').as('dashboard');
   *      // the route name will be admin.dashboard
   *   })
   *   .as('admin')
   */


  _createClass(Group, [{
    key: "as",
    value: function as(name) {
      this._routes.forEach(function (route) {
        if (route.name.length > 0) {
          route.name = "".concat(name, ".").concat(route.name);
        }
      });

      return this;
    }
    /**
     * @description
     * Prefix group of routes.
     * Also see [Route.prefix](https://github.com/samueljoos/next-avenues/blob/master/docs/route.md#prefixprefix)
     *
     * @function prefix
     *
     * @param {string} prefix Prefix for the route paths.
     * @returns {Group}
     *
     * @example
     * router
     *   .group(() => {
     *      router.add('/articles', 'articles').as('articles');
     *      // the resolved route path will be /api/v1/articles
     *   })
     *   .prefix('api/v1')
     */

  }, {
    key: "prefix",
    value: function prefix(_prefix) {
      this._routes.forEach(function (route) {
        return route.prefix(_prefix);
      });

      return this;
    }
    /**
     * @description
     * Add domain to a group of routes.
     * Also see [Route.domain](https://github.com/samueljoos/next-avenues/blob/master/docs/route.md#domaindomain)
     *
     * @function domain
     *
     * @param  {string} domain Domain for the routes.
     * @returns {Group}
     *
     * @example
     * router
     *   .group(() => {
     *      router.add('/', 'home').as('home');
     *      // the resolved route path will be http://next-avenues.com/
     *   })
     *   .domain('next-avenues.com')
     */

  }, {
    key: "domain",
    value: function domain(_domain) {
      this._routes.forEach(function (route) {
        return route.domain(_domain);
      });

      return this;
    }
    /**
     * @description
     * Add data to a group of routes.
     * Also see [Route.data](https://github.com/samueljoos/next-avenues/blob/master/docs/route.md#datadata)
     *
     * @function data
     *
     * @param  {Object} data Data for the routes.
     * @returns {Group}
     *
     * @example
     * router
     *   .group(() => {
     *      router.add('/', 'home').as('home');
     *      // the data object will be provided on the currentRoute object
     *   })
     *   .data({ lang: 'nl' })
     */

  }, {
    key: "data",
    value: function data(_data) {
      this._routes.forEach(function (route) {
        return route.data(_data);
      });

      return this;
    }
  }]);

  return Group;
}();

var _default = Group;
exports.default = _default;