"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

require("core-js/modules/es6.array.for-each");

require("core-js/modules/es6.array.filter");

require("core-js/modules/web.dom.iterable");

require("core-js/modules/es6.array.iterator");

require("core-js/modules/es6.object.keys");

require("core-js/modules/es6.object.define-property");

require("core-js/modules/es6.regexp.split");

require("core-js/modules/es6.regexp.match");

require("core-js/modules/es6.date.to-json");

require("core-js/modules/es6.array.find");

require("core-js/modules/es6.function.bind");

var _Route = _interopRequireDefault(require("./Route"));

var _Group = _interopRequireDefault(require("./Group"));

var _Store = _interopRequireDefault(require("./Store"));

var _url = require("url");

var _utils = require("./utils");

var _router = _interopRequireDefault(require("next/router"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

/**
 * @description
 * Router is the public interface used to define
 * routes, groups and Link components.
 *
 * @singleton
 *
 * @class Router
 */
var Router =
/*#__PURE__*/
function () {
  function Router() {
    _classCallCheck(this, Router);

    this.getRequestHandler = this.getRequestHandler.bind(this);
    this.NextRouter = _router.default;

    this._initialize();
  }
  /**
   * @description
   * Creates a new route which resolves to a Next.js page component.
   * @function add
   * @param {string} route The route name.
   * @param {string} page The Next.js page component.
   * @return {Route}
   */


  _createClass(Router, [{
    key: "add",
    value: function add(route, page) {
      var routeInstance = new _Route.default(this, route, page);

      _Store.default.add(routeInstance);

      return routeInstance;
    }
    /**
     * @description
     * Resolves and returns the route that matches given **url** and **host**
     *
     * **Note:** The first matching route will be used. So make
     * sure the generic routes are created after the
     * static routes.
     * @function match
     * @param {string} url Url string to find a match for.
     * @param {string} host Domain to find a match for.
     * @returns {Object}
     */

  }, {
    key: "match",
    value: function match(url, host) {
      var protocol = "".concat(this.protocol, "://");
      var parsedHost = (0, _url.parse)(protocol + host);
      var domain = parsedHost.hostname;
      var parsedUrl = (0, _url.parse)(url, true);
      var pathname = parsedUrl.pathname,
          query = parsedUrl.query;
      var resolvedUrl = {};
      /*
      * Find the first matching route.
      */

      var matchingRoute = _Store.default.list().find(function (route) {
        resolvedUrl = route.resolve(pathname, domain);
        return resolvedUrl;
      });
      /*
      * Return null when unable to find a route.
      */


      if (!matchingRoute) {
        return {};
      }

      return _objectSpread({}, matchingRoute.toJSON(), {
        port: parsedHost.port,
        parsedUrl: parsedUrl,
        pathname: pathname,
        query: _objectSpread({}, query, resolvedUrl.subdomains),
        data: matchingRoute.data,
        params: resolvedUrl.params,
        domain: domain
      });
    }
    /**
     * @description
     * Create a group of routes.
     * Also see [Group](https://github.com/samueljoos/next-avenues/blob/master/docs/group.md).
     *
     * @function group
     *
     * @param {Function} callback Callback which should only contain calls to [Router.add](https://github.com/samueljoos/next-avenues/blob/master/docs/router.md#routeraddroute-page).
     * @param {string} [name] Same as using [Route.as](https://github.com/samueljoos/next-avenues/blob/master/docs/group.md#asname).
     * @returns {Group}
     *
     * @example
     * routes.group(() => {
     *     routes.add('/', 'dashboard')
     *     // the route name will be admin.dashboard
     * }, 'admin')
     */

  }, {
    key: "group",
    value: function group(callback, name) {
      this._validateGroupClosure(callback);

      this._validateNestedGroups();

      _Store.default.breakpoint(name);

      callback();
      /*
      * Create a new group and pass all the routes
      * to the group.
      */

      var group = new _Group.default(_Store.default.breakpointRoutes());

      if (name) {
        group.as(name);
      }

      _Store.default.releaseBreakpoint();

      return group;
    }
    /**
     * @description
     * Returns an array of all the registered routes
     *
     * @function list
     *
     * @returns {Array}
     */

  }, {
    key: "list",
    value: function list() {
      return _Store.default.list();
    }
    /**
     * @description
     * Return the current active route.
     * This is usualy called inside the getInitialProps a Next.js page component.
     *
     * @function getCurrentRoute
     * @returns {Object}
     */

  }, {
    key: "getCurrentRoute",
    value: function getCurrentRoute() {
      var path;
      var domain;

      if (typeof window !== 'undefined') {
        path = this.path || document.location.href;
        domain = document.location.host;
      } else {
        path = this.currentUrl;
        domain = this.currentHost;
      }

      return this.match(path, domain);
    }
    /**
     * @description
     * Middleware function for your nextjs server setup.
     *
     * @function getRequestHandler
     * @param {Next.App} app The value of Next.js next().
     * @param {Function} [customHandler] Callback to customise the renderHandler parameters.
     *
     * @returns {Function}
     */

  }, {
    key: "getRequestHandler",
    value: function getRequestHandler(app, customHandler) {
      var _this = this;

      var nextHandler = app.getRequestHandler();
      return function (req, res) {
        var route = _this.match(req.url, req.headers.host);

        _this.currentUrl = req.url;
        _this.currentHost = req.headers.host;
        _this.port = route.port;
        _this.domain = route.domain;
        _this.protocol = req.headers.referer && req.headers.referer.split('://')[0] || 'http';

        if (route.pathname) {
          if (customHandler) {
            customHandler({
              req: req,
              res: res,
              route: route,
              query: route.query
            });
          } else {
            app.render(req, res, '/' + route.page, route.query);
          }
        } else {
          nextHandler(req, res, route.parsedUrl);
        }
      };
    }
    /**
     * @description
     * Push State helper for navigating to a route.
     * **note:** This doesn't work serverside.
     *
     * @param {string} name The route name.
     * @param {Object} [params] The route parameters.
     * @param {Object} [query] The route query parameters.
     *
     * @example
     * router.add('/post/:slug','blog-post').as('blog-post');
     * router.pushRoute('blog-post', {slug:'post-slug'}, {order:'1'});
     * // resolves to /post/post-slug?order=1
     */

  }, {
    key: "pushRoute",
    value: function pushRoute(name, params, query) {
      this._browserHistoryApply('push', name, params, query);
    }
    /**
     * @description
     * Replace State helper for navigating to a route.
     * **note:** This doesn't work serverside.
     *
     * @param {string} name The route name.
     * @param {Object} [params] The route parameters.
     * @param {Object} [query] The route query parameters.
     *
     * @example
     * router.add('/post/:slug','blog-post').as('blog-post');
     * router.replaceRoute('blog-post', {slug:'post-slug'}, {order:'1'});
     * // resolves to /post/post-slug?order=1
     */

  }, {
    key: "replaceRoute",
    value: function replaceRoute(name, params, query) {
      this._browserHistoryApply('replace', name, params, query);
    }
    /**
     * @description
     * Prefetch a route
     * **note:** This doesn't work serverside.
     *
     * @param {string} name The route name.
     * @param {Object} [params] The route parameters.
     * @param {Object} [query] The route query parameters.
     *
     * @example
     * router.add('/post/:slug','blog-post').as('blog-post');
     * router.prefetchRoute('blog-post', {slug:'post-slug'}, {order:'1'});
     * // prefetches the data for /post/post-slug?order=1
     */

  }, {
    key: "prefetchRoute",
    value: function prefetchRoute(name, params, query) {
      this._browserHistoryApply('prefetch', name, params, query);
    } //////
    // Private functions
    //////

    /**
     * @description
     * Initialize the client url location data
     *
     * @function _validateGroupClosure
     *
     * @returns {void}
     *
     * @private
     */

  }, {
    key: "_initialize",
    value: function _initialize() {
      var _this2 = this;

      if (typeof window !== 'undefined') {
        this.port = document.location.port;
        this.domain = document.location.host.split(':')[0];
        this.protocol = document.location.protocol.split(':')[0];
        this.NextRouter.events.on('routeChangeStart', function (url) {
          _this2.path = url;
        });
      }
    }
    /**
     * @description
     * Validates the group closure to make sure
     * it is a function
     *
     * @function _validateGroupClosure
     *
     * @param  {Function} callback
     *
     * @private
     */

  }, {
    key: "_validateGroupClosure",
    value: function _validateGroupClosure(callback) {
      if (typeof callback !== 'function') {
        throw (0, _utils.errorMessage)('Route.group expects a callback', callback);
      }
    }
    /**
     * @description
     * Validates that nested groups are not created.
     *
     * @function _validateNestedGroups
     *
     * @private
     */

  }, {
    key: "_validateNestedGroups",
    value: function _validateNestedGroups() {
      if (_Store.default.hasBreakpoint()) {
        _Store.default.releaseBreakpoint();

        throw (0, _utils.errorMessage)('Nested route groups are not allowed', 500, 'E_NESTED_ROUTE_GROUPS');
      }
    }
    /**
     * @description
     * Helper function for browser history methods.
     * Used by [router.pushRoute](https://github.com/samueljoos/next-avenues/blob/master/docs/router.md#pushroutenameparamsquery) [router.replaceRoute](https://github.com/samueljoos/next-avenues/blob/master/docs/router.md#replaceroutenameparamsquery) [router.prefetchRoute](https://github.com/samueljoos/next-avenues/blob/master/docs/router.md#prefetchroutenameparamsquery)
     *
     * @param {string} method Should be one of push, replace or prefetch.
     * @param {string} name The route name.
     * @param {Object} params The route Params.
     * @param {Object} query The route query.
     */

  }, {
    key: "_browserHistoryApply",
    value: function _browserHistoryApply(method, name, params, query) {
      if (typeof window === 'undefined') {
        throw (0, _utils.errorMessage)('Pushing routes is only available in the client', 'router.push');
      }

      var route = _Store.default.find(name, this.domain);

      var nextLinkProps = route.getNextLinkProps(params, {
        domain: this.domain,
        protocol: this.protocol,
        query: query
      });
      this.NextRouter[method](nextLinkProps.href, nextLinkProps.as);
    }
  }]);

  return Router;
}();

var _default = new Router();

exports.default = _default;