"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

require("core-js/modules/es6.object.define-property");

require("core-js/modules/es6.function.name");

require("core-js/modules/es6.array.find");

require("core-js/modules/web.dom.iterable");

require("core-js/modules/es6.array.for-each");

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

/*
 * Next Avenues
 *
 * (c) Samuel Joos
 *
 * Based on the work of
 * (c) Harminder Virk <virk@adonisjs.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
*/

/**
 * Route store is used to store registered routes as an
 * array. It is a singleton store to be exported and
 * used by an part of the application to store
 * routes.
 *
 *
 * @class RouteStore
 * @static
 */
var Store =
/*#__PURE__*/
function () {
  function Store() {
    _classCallCheck(this, Store);

    this._routes = [];
    this.releaseBreakpoint();
  }
  /**
  * @description
  * Add a breakpoint to routes. All routes after the
  * breakpoint will be recorded seperately. Helpful
  * for @ref(Route/group).
  *
  * Also only one breakpoint at a time is allowed.
  *
  * @function breakpoint
  *
  * @param {string} name Breakpoint name.
  */


  _createClass(Store, [{
    key: "breakpoint",
    value: function breakpoint() {
      var name = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
      this._breakpoint.enabled = true;
      this._breakpoint.name = name;
    }
    /**
     * @description
    * Returns a boolean indicating whether breakpoint
    * is enabled or not.
    *
    * @function hasBreakpoint
    *
    * @returns {boolean}
    */

  }, {
    key: "hasBreakpoint",
    value: function hasBreakpoint() {
      return this._breakpoint.enabled;
    }
    /**
    * @description
    * Returns the routes recorded during
    * breakpoint.
    *
    * @function breakpointRoutes
    *
    * @returns {Array}
    */

  }, {
    key: "breakpointRoutes",
    value: function breakpointRoutes() {
      return this._breakpoint.routes;
    }
    /**
    * @description
    * Release the breakpoint.
    *
    * @function releaseBreakpoint
    */

  }, {
    key: "releaseBreakpoint",
    value: function releaseBreakpoint() {
      this._breakpoint = {
        enabled: false,
        routes: [],
        name: null
      };
    }
    /**
    * @description
    * Add a route to the store.
    * This function is used by [Router.add](https://github.com/samueljoos/next-avenues/blob/master/docs/router.md#routeraddroute-page)
    * Also see [Route](https://github.com/samueljoos/next-avenues/blob/master/docs/route.md)
    *
    * @function add
    *
    * @param  {Route} route Route instance.
    */

  }, {
    key: "add",
    value: function add(route) {
      if (this.hasBreakpoint()) {
        this._breakpoint.routes.push(route);
      }

      this._routes.push(route);
    }
    /**
    * @description
    * Remove route from the store.
    *
    * @function remove
    *
    * @param  {Route} routeToRemove Route instance.
    */

  }, {
    key: "remove",
    value: function remove(routeToRemove) {
      var _this = this;

      var removeCallback = function removeCallback(route, index) {
        if (route === routeToRemove) {
          delete _this._routes[index];
        }
      };

      this._routes.forEach(removeCallback);

      if (this.hasBreakpoint()) {
        this._breakpoint.routes.forEach(removeCallback);
      }
    }
    /**
    * @description
    * Clear all the routes store so far.
    *
    * @function clear
    */

  }, {
    key: "clear",
    value: function clear() {
      this._routes = [];
    }
    /**
    * @description
    * Find a route with name or it's url
    *
    * @function find
    *
    * @param {string} routeNameOrHandler Route name or path template.
    * @param {string} domain For domain matching not used for subdomain matching.
    *
    * @returns {Object|Null}
    */

  }, {
    key: "find",
    value: function find(routeNameOrHandler, domain) {
      return this._routes.find(function (route) {
        var isName = route.name === routeNameOrHandler;
        var isRoute = route._route === routeNameOrHandler;
        var isDomain = route._domain === domain;
        return route._domain && route.domainKeys.length === 0 ? isDomain && (isName || isRoute) : isName || isRoute;
      });
    }
    /**
    * @description
    * Returns a list of stored routes.
    *
    * @function list
    *
    * @returns {Array}
    */

  }, {
    key: "list",
    value: function list() {
      return this._routes;
    }
  }]);

  return Store;
}();

var _default = new Store();

exports.default = _default;