"use strict";

require("core-js/modules/es6.object.define-property");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.errorMessage = exports.toQuerystring = void 0;

require("core-js/modules/es6.array.is-array");

require("core-js/modules/web.dom.iterable");

require("core-js/modules/es6.array.iterator");

require("core-js/modules/es6.object.keys");

require("core-js/modules/es6.array.filter");

require("core-js/modules/es6.array.map");

/*
 * Next Avenues
 *
 * (c) Samuel Joos
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
*/

/**
 * @description
 * Create a url query string from an object
 *
 * @function toQuerystring
 * @param {Object.<string, string>} obj
 */
var toQuerystring = function toQuerystring(obj) {
  return '?' + Object.keys(obj).filter(function (key) {
    return obj[key] !== null && obj[key] !== undefined;
  }).map(function (key) {
    var value = obj[key];

    if (Array.isArray(value)) {
      value = value.join('/');
    }

    return [encodeURIComponent(key), encodeURIComponent(value)].join('=');
  }).join('&');
};
/**
 * @description
 * Format error Message
 *
 * @param {string} message
 * @param {*} subject
 * @returns {string}
 */


exports.toQuerystring = toQuerystring;

var errorMessage = function errorMessage(message, subject) {
  return "".concat(message, " for ").concat(subject);
};

exports.errorMessage = errorMessage;